"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import io
from typing import IO, Literal, Union

import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict

from friendli_core.types import (
    UNSET,
    UNSET_SENTINEL,
    BaseModel,
    Nullable,
    OptionalNullable,
)
from friendli_core.utils import FieldMetadata, HeaderMetadata, QueryParamMetadata

Direction = Literal["asc", "desc"]


class ListDatasetsRequestTypedDict(TypedDict):
    project_id: str
    cursor: NotRequired[Nullable[Union[bytes, IO[bytes], io.BufferedReader]]]
    limit: NotRequired[Nullable[int]]
    direction: NotRequired[Nullable[Direction]]
    name_search: NotRequired[Nullable[str]]
    x_friendli_team: NotRequired[Nullable[str]]
    r"""ID of team to run requests as (optional parameter)."""


class ListDatasetsRequest(BaseModel):
    project_id: Annotated[
        str,
        pydantic.Field(alias="projectId"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]

    cursor: Annotated[
        OptionalNullable[Union[bytes, IO[bytes], io.BufferedReader]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    limit: Annotated[
        OptionalNullable[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = 20

    direction: Annotated[
        OptionalNullable[Direction],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    name_search: Annotated[
        OptionalNullable[str],
        pydantic.Field(alias="nameSearch"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET

    x_friendli_team: Annotated[
        OptionalNullable[str],
        pydantic.Field(alias="X-Friendli-Team"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = UNSET
    r"""ID of team to run requests as (optional parameter)."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "cursor",
            "limit",
            "direction",
            "nameSearch",
            "X-Friendli-Team",
        ]
        nullable_fields = [
            "cursor",
            "limit",
            "direction",
            "nameSearch",
            "X-Friendli-Team",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
