"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import Literal

DedicatedDatasetModalityType = Literal["VIDEO", "IMAGE", "AUDIO", "TEXT"]
r"""Modality type."""
