"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List, Optional

from typing_extensions import NotRequired, TypedDict

from friendli_core.types import BaseModel

from .dedicateddatasetmodalitytype import DedicatedDatasetModalityType


class DedicatedDatasetModalityTypedDict(TypedDict):
    r"""Dataset modality."""

    input_modals: NotRequired[List[DedicatedDatasetModalityType]]
    output_modals: NotRequired[List[DedicatedDatasetModalityType]]


class DedicatedDatasetModality(BaseModel):
    r"""Dataset modality."""

    input_modals: Optional[List[DedicatedDatasetModalityType]] = None

    output_modals: Optional[List[DedicatedDatasetModalityType]] = None
