"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

import pydantic
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel


class DeleteSamplesResponseTypedDict(TypedDict):
    r"""Delete samples response."""

    sample_ids: List[str]
    r"""List of sample IDs that were deleted from the dataset."""


class DeleteSamplesResponse(BaseModel):
    r"""Delete samples response."""

    sample_ids: Annotated[List[str], pydantic.Field(alias="sampleIds")]
    r"""List of sample IDs that were deleted from the dataset."""
