# Copyright (c) 2025-present, FriendliAI Inc. All rights reserved.

"""Friendli Python SDK."""

from __future__ import annotations

from friendli_core import VERSION  # noqa: F401

from .friendli import AsyncFriendli, SyncFriendli  # noqa: F401
