"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

import pydantic
from typing_extensions import Annotated, TypedDict

from friendli_core.types import BaseModel


class VersionInfoTypedDict(TypedDict):
    r"""Version info."""

    comment: str
    r"""Comment for the version."""
    created_at: int
    r"""Unix timestamp (in seconds) of when the version was created."""
    id: str
    r"""ID of the version."""


class VersionInfo(BaseModel):
    r"""Version info."""

    comment: str
    r"""Comment for the version."""

    created_at: Annotated[int, pydantic.Field(alias="createdAt")]
    r"""Unix timestamp (in seconds) of when the version was created."""

    id: str
    r"""ID of the version."""
