"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations

from typing import List

from typing_extensions import TypedDict

from friendli_core.types import BaseModel


class AddSamplesResponseTypedDict(TypedDict):
    r"""Add samples response."""

    samples: List[List[str]]
    r"""List of sample IDs that were added to the dataset."""


class AddSamplesResponse(BaseModel):
    r"""Add samples response."""

    samples: List[List[str]]
    r"""List of sample IDs that were added to the dataset."""
